/*
 * T-Plan Robot Enterprise, automated testing tool.
 * Copyright (C) 2009-2012 T-Plan Limited (http://www.t-plan.com),
 * Cloisters House, 8 Battersea Park Road, London, SW8 4BG, United Kingdom.
 * All rights reserved.
 */

import java.io.File;
import java.lang.reflect.Method;

/**
 * Script Starter v2 for T-Plan Robot Enterprise
 *
 * This tool can be used to kick off multiple T-Plan Robot Enterprise test
 * scripts in parallel.
 */
public class StartScripts {

    public static void main(String args[]) {
        if (args.length != 1) {
            System.out.println(""
                    + "Start one or more T-Plan Robot Enterprise scripts in parallel.\n"
                    + "(C) T-Plan Ltd, http://www.t-plan.com\n\n"
                    + "Usage: java -cp scriptstarter.jar" + File.pathSeparator + "robot.jar " + StartScripts.class.getName() + " <text_file>\n\n"
                    + "The text file must contain one or more lines where each line\n"
                    + "specifies CLI parameters of a single T-Plan Robot process.\n"
                    + "Empty lines and lines starting with # will be ignored.\n"
                    + "For a complete list of supported CLI options see:\n\n"
                    + "  http://www.t-plan.com/robot/docs/latest/cli/clioptions.html\n\n"
                    + "For example, the following text file will start two parallel\n"
                    + "test processes:\n\n"
                    + "  # Start Script1 on VNC server at rfb://192.168.100.7:5900\n"
                    + "  -c rfb://192.168.100.7:5900 -r C:\\MyProject\\tpr\\Script1.tpr -n\n\n"
                    + "  # Start Script2 on another VNC server at rfb://192.168.100.11:5900\n"
                    + "  -c rfb://192.168.100.11:5900 -r C:\\MyProject\\tpr\\Script2.tpr -n\n\n"
                    + "For more details see the plugin web page at:\n"
                    + "  http://www.t-plan.com/robot/docs/plugins/scriptstarter.html");
            System.exit(1);
        }
        try {
            // Calling the functionality through the Reflection API will allow us
            // to display a meaningful message when the robot.jar file is not on the
            // class path.
            Class clazz = Class.forName("ScriptExecutor");
            Method method = clazz.getMethod("execute", String.class);
            method.invoke(null, args[0]);
        } catch (Throwable t) {
            // An ExceptionInInitializerError or NoClassDefFoundError indicates that the robot.jar
            // file is not on the class path. 
            if (t instanceof ExceptionInInitializerError || t instanceof NoClassDefFoundError) {
                System.out.println("The robot.jar file is not on the class path. "
                        + "Please read the documentation at http://www.t-plan.com/robot/docs/plugins/scriptstarter.html "
                        + "on how to put it onto the Java class path.");
            } else {
                System.out.println("An unknown error was thrown:");
                t.printStackTrace();
            }
            System.exit(1);
        }
    }
}
